==> reposurgeon_4.31.orig.tar.xz: reposurgeon-4.31/test/repocutter-pop.sh <==
#!/bin/sh
## Test path-seqment popping
${REPOCUTTER:-repocutter} -q pop <<EOF
SVN-fs-dump-format-version: 2

UUID: be5bedff-a577-4def-8afe-cf522686966a

Revision-number: 0
Prop-content-length: 56
Content-length: 56

K 8
svn:date
V 27
2011-11-30T16:40:02.180831Z
PROPS-END

Revision-number: 1
Prop-content-length: 177
Content-length: 177

K 7
svn:log
V 79
A vanilla repository - standard layout, linear history, no tags, no branches. 

K 10
svn:author
V 3
esr
K 8
svn:date
V 27
2011-11-30T16:41:55.154754Z
PROPS-END

Node-path: popsegment/branches
Node-kind: dir
Node-action: add
Prop-content-length: 10
Content-length: 10

PROPS-END


Node-path: popsegment/tags
Node-kind: dir
Node-action: add
Prop-content-length: 10
Content-length: 10

PROPS-END


Node-path: popsegment/trunk
Node-kind: dir
Node-action: add
Prop-content-length: 10
Content-length: 10

PROPS-END


Revision-number: 2
Prop-content-length: 114
Content-length: 114

K 7
svn:log
V 16
First revision.

K 10
svn:author
V 3
esr
K 8
svn:date
V 27
2011-11-30T16:43:52.297468Z
PROPS-END

Node-path: popsegment/trunk/README
Node-kind: file
Node-action: add
Prop-content-length: 10
Text-content-length: 23
Text-content-md5: a60319cd0397d5c9bcc0652f9a54c56c
Text-content-sha1: 29cb70183455e46d32a129a75de9fb544c248c08
Content-length: 33

PROPS-END
This is a sample file.


Revision-number: 3
Prop-content-length: 115
Content-length: 115

K 7
svn:log
V 17
Second revision.

K 10
svn:author
V 3
esr
K 8
svn:date
V 27
2011-11-30T16:45:21.726591Z
PROPS-END

Node-path: popsegment/trunk/README
Node-kind: file
Node-action: change
Text-content-length: 68
Text-content-md5: 6beeadee983f7374617861c5e603d022
Text-content-sha1: c7b0320947b6d07945a529d01abb22cebcbf799d
Content-length: 68

This is a sample file.

This is our first line of modified content.


Revision-number: 4
Prop-content-length: 114
Content-length: 114

K 7
svn:log
V 16
Third revision.

K 10
svn:author
V 3
esr
K 8
svn:date
V 27
2011-11-30T16:46:05.627972Z
PROPS-END

Node-path: popsegment/trunk/README
Node-kind: file
Node-action: change
Text-content-length: 114
Text-content-md5: 6b367fede2aa8d872192cbe7f184b0ce
Text-content-sha1: 9b38d27fe0acb2c33072d195a1e05e4b360c9f21
Content-length: 114

This is a sample file.

This is our first line of modified content.

This is our second line of modified content.
EOF

==> reposurgeon_4.35.orig.tar.xz: reposurgeon-4.35/test/repocutter-pop.sh <==
#!/bin/sh
## Test path-seqment popping
# shellcheck disable=SC2086
${REPOCUTTER:-repocutter} -q -t "$(basename $0)" pop 2>&1 <<EOF
SVN-fs-dump-format-version: 2

UUID: be5bedff-a577-4def-8afe-cf522686966a

Revision-number: 0
Prop-content-length: 56
Content-length: 56

K 8
svn:date
V 27
2011-11-30T16:40:02.180831Z
PROPS-END

Revision-number: 1
Prop-content-length: 177
Content-length: 177

K 7
svn:log
V 79
A vanilla repository - standard layout, linear history, no tags, no branches. 

K 10
svn:author
V 3
esr
K 8
svn:date
V 27
2011-11-30T16:41:55.154754Z
PROPS-END

Node-path: popsegment/branches
Node-kind: dir
Node-action: add
Prop-content-length: 10
Content-length: 10

PROPS-END


Node-path: popsegment/tags
Node-kind: dir
Node-action: add
Prop-content-length: 10
Content-length: 10

PROPS-END


Node-path: popsegment/trunk
Node-kind: dir
Node-action: add
Prop-content-length: 10
Content-length: 10

PROPS-END


Revision-number: 2
Prop-content-length: 114
Content-length: 114

K 7
svn:log
V 16
First revision.

K 10
svn:author
V 3
esr
K 8
svn:date
V 27
2011-11-30T16:43:52.297468Z
PROPS-END

Node-path: popsegment/trunk/README
Node-kind: file
Node-action: add
Prop-content-length: 10
Text-content-length: 23
Text-content-md5: a60319cd0397d5c9bcc0652f9a54c56c
Text-content-sha1: 29cb70183455e46d32a129a75de9fb544c248c08
Content-length: 33

PROPS-END
This is a sample file.


Revision-number: 3
Prop-content-length: 115
Content-length: 115

K 7
svn:log
V 17
Second revision.

K 10
svn:author
V 3
esr
K 8
svn:date
V 27
2011-11-30T16:45:21.726591Z
PROPS-END

Node-path: popsegment/trunk/README
Node-kind: file
Node-action: change
Text-content-length: 68
Text-content-md5: 6beeadee983f7374617861c5e603d022
Text-content-sha1: c7b0320947b6d07945a529d01abb22cebcbf799d
Content-length: 68

This is a sample file.

This is our first line of modified content.


Revision-number: 4
Prop-content-length: 114
Content-length: 114

K 7
svn:log
V 16
Third revision.

K 10
svn:author
V 3
esr
K 8
svn:date
V 27
2011-11-30T16:46:05.627972Z
PROPS-END

Node-path: popsegment/trunk/README
Node-kind: file
Node-action: change
Text-content-length: 114
Text-content-md5: 6b367fede2aa8d872192cbe7f184b0ce
Text-content-sha1: 9b38d27fe0acb2c33072d195a1e05e4b360c9f21
Content-length: 114

This is a sample file.

This is our first line of modified content.

This is our second line of modified content.
EOF
